Author: Wouter van Wijk
Description: MusicBox

- Now Playing
- Playlists
- Browse
- Queue
- Search
- Radio
- Fullscreen
- Exit Fullscreen
- Settings
- System
- Volume

Close

###

####

Close

#### bbb

- Play
- Play Track Next
- Add Track to Bottom of Queue
- Add all to Bottom of Queue
- Show Album
- Show Artist

## Artists

- Play
- Remove from Queue
- Show Album
- Show Artist

## Artists

# Musicbox

Back

### Browse

####

###

-

0:00 0:00 Position
Clear

#### Play Queue

###

#####

###

#### Artists

#### Albums

#### Tracks

#### Radio

Add an url of a radio station stream that you want to listen to in the boxes below. The last 25 stations are saved locally (not on the server yet). To find stations, use the Browse function with extensions like Dirble or TuneIn, the right values will appear in these boxes automatically. Or use websites like Listenlive or Dirble.